![alt text](./docs/source/img/oc.png)
### The minimalist - all purpose - color class for printing

    Default values set for standard printing

![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-20-05.png)

    Instantiate with string for class colors
    
![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-22-07.png)

    Or set colors with integers

![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-23-05.png)

    The format doesn't matter
    
![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-24-03.png)

    Create subclasses

![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-28-55.png)

    Instead of using print() use get() to manipulate strings
    
![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2012-31-32.png)

    Subclass contained in self.__dict__

![alt text](./docs/source/img/Screenshot%20from%202019-10-02%2014-02-53.png)
